from optparse import Option
from typing import Optional


def load_dotenv():
    print('loading dotenv-vault.')